@@ -3,13 +3,12 @@
 /**
  * mailbox_display.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @version $Id: mailbox_display.php,v 1.321.2.32 2006/02/03 22:27:47 jervfors Exp $
+ * @copyright 1999-2010 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: mailbox_display.php 13902 2010-02-04 20:13:23Z pdontthink $
  * @package squirrelmail
  */
 
@@ -42,7 +41,7 @@ function elapsed($start)
 
 function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                           $start_msg, $where, $what) {
-    global $checkall,
+    global $checkall, $preselected,
            $color, $msgs, $msort, $td_str, $msg,
            $default_use_priority,
            $message_highlight_list,
@@ -115,7 +114,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
         }
     }
     $senderName = str_replace('&nbsp;',' ',$senderName);
-    echo html_tag( 'tr','','','','VALIGN="top"') . "\n";
+    echo html_tag( 'tr','','','','valign="top"') . "\n";
 
     if (isset($msg['FLAG_FLAGGED']) && ($msg['FLAG_FLAGGED'] == true)) {
         $flag = "<font color=\"$color[2]\">";
@@ -195,17 +194,21 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     if (!isset($hlt_color)) {
         $hlt_color = $color_string;
     }
-    $checked = ($checkall == 1) ? ' CHECKED' : '';
+    if ($checkall == 1 || in_array($msg['ID'], $preselected))
+        $checked = ' checked="checked"';
+    else
+        $checked = '';
     $col = 0;
     $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
 //    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
-    $subject = truncateWithEntities(str_replace('&nbsp;',' ',$msg['SUBJECT']), $truncate_subject);
+    $subject = sm_truncate_string(str_replace('&nbsp;',' ',$msg['SUBJECT']), $truncate_subject, '...', TRUE);
     if (sizeof($index_order)) {
         foreach ($index_order as $index_order_part) {
             switch ($index_order_part) {
             case 1: /* checkbox */
                 echo html_tag( 'td',
-                               "<input type=checkbox name=\"msg[$t]\" value=\"".$msg['ID']."\"$checked>",
+                               "<input type=\"checkbox\" name=\"msg[$t]\" id=\"msg".$msg['ID'].
+                                   "\" value=\"".$msg['ID']."\"$checked>",
                                'center',
                                $hlt_color );
                 break;
@@ -213,10 +216,12 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 $from_xtra = '';
                 $from_xtra = 'title="' . $senderFrom . '"';
                 echo html_tag( 'td',
-                               $italic . $bold . $flag . $fontstr . truncateWithEntities($senderName, $truncate_sender) .
+                    html_tag('label',
+                               $italic . $bold . $flag . $fontstr . sm_truncate_string($senderName, $truncate_sender, '...', TRUE) .
                                $fontstr_end . $flag_end . $bold_end . $italic_end,
-                               'left',
-                               $hlt_color, $from_xtra );
+                           '','','for="msg'.$msg['ID'].'"'),
+                           'left',
+                           $hlt_color, $from_xtra );
                 break;
             case 3: /* date */
                 $date_string = $msg['DATE_STRING'] . '';
@@ -256,10 +261,11 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 $td_str = "<b><small>";
 
                 if (isset($msg['FLAG_ANSWERED']) && $msg['FLAG_ANSWERED'] == true) {
+                    // i18n: "A" is short for "Answered". Make sure that two icon strings aren't translated to the same character (only in 1.5).
                     $td_str .= _("A");
                     $stuff = true;
                 }
-                if ($msg['TYPE0'] == 'multipart') {
+                if ($msg['TYPE0'] == 'multipart' && $msg['TYPE1'] == 'mixed') {
                     $td_str .= '+';
                     $stuff = true;
                 }
@@ -300,8 +306,8 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
         }
     }
     if ($not_last) {
-        echo '</tr>' . "\n" . '<tr><td COLSPAN="' . $col . '" BGCOLOR="' .
-             $color[0] . '" HEIGHT="1"></td></tr>' . "\n";
+        echo '</tr>' . "\n" . '<tr><td colspan="' . $col . '" bgcolor="' .
+             $color[0] . '" height="1"></td></tr>' . "\n";
     } else {
         echo '</tr>'."\n";
     }
@@ -340,12 +346,12 @@ function getSelfSortMessages($imapConnection, $start_msg, $show_num,
     $msgs = array();
     if ($num_msgs >= 1) {
         $id = sqimap_get_php_sort_order ($imapConnection, $mbxresponse);
-        if ($sort < 6 ) {
+        if ($sort != 6 ) {
             $end = $num_msgs;
             $end_loop = $end;
-	    /* set shownum to 999999 to fool sqimap_get_small_header_list
-	       and rebuild the msgs_str to 1:* */
-	    $show_num = 999999;
+            /* set shownum to 999999 to fool sqimap_get_small_header_list
+               and rebuild the msgs_str to 1:* */
+            $show_num = 999999;
         } else {
             /* if it's not sorted */
             if ($start_msg + ($show_num - 1) < $num_msgs) {
@@ -437,22 +443,22 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
             $mode = '';
         }
 
-	if ($use_cache) {
-	    sqgetGlobalVar('msgs', $msgs, SQ_SESSION);
-	    sqgetGlobalVar('msort', $msort, SQ_SESSION);
-	} else {
-    	    sqsession_unregister('msort');
-    	    sqsession_unregister('msgs');
-	}
+        if ($use_cache) {
+            sqgetGlobalVar('msgs', $msgs, SQ_SESSION);
+            sqgetGlobalVar('msort', $msort, SQ_SESSION);
+        } else {
+            sqsession_unregister('msort');
+            sqsession_unregister('msgs');
+        }
         switch ($mode) {
             case 'thread':
                 $id   = get_thread_sort($imapConnection);
                 $msgs = getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $id);
                 if ($msgs === false) {
-                    echo '<b><small><center><font color=red>' .
+                    echo '<b><small><center><font color="red">' .
                         _("Thread sorting is not supported by your IMAP server.") . '<br />' .
                         _("Please contact your system administrator and report this error.") .
-                        '</center></small></b>';
+                        '</font></center></small></b>';
                     $thread_sort_messages = 0;
                     $msort = $msgs = array();
                 } else {
@@ -464,10 +470,10 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                 $id   = sqimap_get_sort_order($imapConnection, $sort, $mbxresponse);
                 $msgs = getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $id);
                 if ($msgs === false) {
-                    echo '<b><small><center><font color=red>' .
+                    echo '<b><small><center><font color="red">' .
                         _( "Server-side sorting is not supported by your IMAP server.") . '<br />' .
                         _("Please contact your system administrator and report this error.") .
-                        '</center></small></b>';
+                        '</font></center></small></b>';
                     $sort = $server_sort_order;
                     $allow_server_sort = FALSE;
                     $msort = $msgs = array();
@@ -481,7 +487,7 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                 if (!$use_cache) {
                     $msgs = getSelfSortMessages($imapConnection, $start_msg, $show_num,
                                                 $num_msgs, $sort, $mbxresponse);
-                    $msort = calc_msort($msgs, $sort);
+                    $msort = calc_msort($msgs, $sort, $mailbox);
                 } /* !use cache */
                 break;
         } // switch
@@ -504,33 +510,42 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     $msg_cnt_str = get_msgcnt_str($start_msg, $end_msg, $num_msgs);
 
     do_hook('mailbox_index_before');
+
+    $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+    $form_name = "FormMsgs" . $safe_name;
+    echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n" .
+        '<input type="hidden" name="smtoken" value="'.sm_generate_security_token().'">' . "\n" .
+        '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
+        '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
+    
     echo '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
     echo '<tr><td>';
 
     mail_message_listing_beginning($imapConnection, $mailbox, $sort,
                                   $msg_cnt_str, $paginator_str, $start_msg);
-    echo '</td></tr>';
     /* line between the button area and the list */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
+    echo '<tr><td height="5" bgcolor="'.$color[4].'"></td></tr>';
 
     echo '<tr><td>';
     echo '    <table width="100%" cellpadding="1" cellspacing="0" align="center"'.' border="0" bgcolor="'.$color[9].'">';
     echo '     <tr><td>';
     echo '       <table width="100%" cellpadding="1" cellspacing="0" align="center" border="0" bgcolor="'.$color[5].'">';
-    echo '<tr><td>';
     printHeader($mailbox, $srt, $color, !$thread_sort_messages);
 
     displayMessageArray($imapConnection, $num_msgs, $start_msg,
-		      $msort, $mailbox, $sort, $color, $show_num,0,0);
-    echo '</td></tr></table></td></tr></table>';
+                        $msort, $mailbox, $sort, $color, $show_num,0,0);
+    echo '</table></td></tr></table>';
 
     mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color);
-    echo '</td></tr></table>';
+    echo '</table>';
+
+    echo "\n</form>\n\n";
+    
     //$t = elapsed($start);
     //echo("elapsed time = $t seconds\n");
 }
 
-function calc_msort($msgs, $sort) {
+function calc_msort($msgs, $sort, $mailbox = 'INBOX') {
 
     /*
      * 0 = Date (up)
@@ -539,6 +554,10 @@ function calc_msort($msgs, $sort) {
      * 3 = Name (dn)
      * 4 = Subject (up)
      * 5 = Subject (dn)
+     * 6 = default no sort
+     * 7 - UNUSED
+     * 8 = Size (up)
+     * 9 = Size (dn)
      */
 
     if (($sort == 0) || ($sort == 1)) {
@@ -546,17 +565,22 @@ function calc_msort($msgs, $sort) {
             $msort[] = $item['TIME_STAMP'];
         }
     } elseif (($sort == 2) || ($sort == 3)) {
+        $fld_sort = (handleAsSent($mailbox)?'TO-SORT':'FROM-SORT');
         foreach ($msgs as $item) {
-            $msort[] = $item['FROM-SORT'];
+            $msort[] = $item[$fld_sort];
         }
     } elseif (($sort == 4) || ($sort == 5)) {
         foreach ($msgs as $item) {
             $msort[] = $item['SUBJECT-SORT'];
         }
+    } elseif (($sort == 8) || ($sort == 9)) {
+       foreach ($msgs as $item) {
+           $msort[] = $item['SIZE'];
+       }
     } else {
         $msort = $msgs;
     }
-    if ($sort < 6) {
+    if ($sort != 6) {
         if ($sort % 2) {
             asort($msort);
         } else {
@@ -614,10 +638,10 @@ function displayMessageArray($imapConnection, $num_msgs, $start_msg,
     /* if there's no messages in this folder */
         echo html_tag( 'tr',
                 html_tag( 'td',
-                          "<BR><b>" . _("THIS FOLDER IS EMPTY") . "</b><BR>&nbsp;",
+                          "<br><b>" . _("THIS FOLDER IS EMPTY") . "</b><br>&nbsp;",
                           'center',
                           $color[4],
-                          'COLSPAN="' . count($index_order) . '"'
+                          'colspan="' . count($index_order) . '"'
                 )
         );
     } elseif ($start_msg == $end_msg) {
@@ -691,21 +715,10 @@ function mail_message_listing_beginning ($imapConnection,
         $source_url = $php_self;
     }
 
-    if (!isset($msg)) {
-        $msg = '';
-    }
-    $moveFields = '<input type="hidden" name="msg" value="'.htmlspecialchars($msg).'">' . "\n" .
-		  '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
-		  '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
-
     /*
      * This is the beginning of the message list table.
      * It wraps around all messages
      */
-    $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
-    $form_name = "FormMsgs" . $safe_name;
-    echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n"
-        . $moveFields . "\n";
 
     if (!empty($paginator) && !empty($msg_cnt_str)) {
 
@@ -720,39 +733,36 @@ function mail_message_listing_beginning ($imapConnection,
                     , '', $color[4], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' )
                 , 'left', '', '' )
             , '', $color[0] )
-	    , '', '', 'border="0" width="100%" cellpadding="1"  cellspacing="0"' );
+         , '', '', 'border="0" width="100%" cellpadding="1"  cellspacing="0"' );
     }
-	/* line between header and button area */
-        echo '</td></tr><tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
+    /* line between header and button area */
+        echo '</td></tr><tr><td height="5" bgcolor="'.$color[4].'"></td></tr>';
 
-        echo '<tr><td>';
         echo html_tag( 'tr' ) . "\n"
         . html_tag( 'td' ,'' , 'left', '', '' )
          . html_tag( 'table' ,'' , '', $color[9], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' )
-	  . '<tr><td>'
+          . '<tr><td>'
            . html_tag( 'table' ,'' , '', $color[0], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' )
             . html_tag( 'tr',
-	        getSmallStringCell(_("Move Selected To"), 'left', 'nowrap') .
-	        getSmallStringCell(_("Transform Selected Messages"), 'right')
+             getSmallStringCell(_("Move Selected To"), 'left', 'nowrap') .
+             getSmallStringCell(_("Transform Selected Messages"), 'right')
             )
             . html_tag( 'tr' ) ."\n"
             . html_tag( 'td', '', 'left', '', 'valign="middle" nowrap' );
             getMbxList($imapConnection);
             echo getButton('SUBMIT', 'moveButton',_("Move")) . "\n";
             echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";
+            do_hook('mailbox_display_buttons');
 
-  echo "      </small></td>\n"
+    echo "      </small></td>\n"
          . html_tag( 'td', '', 'right', '', 'nowrap' );
 
-
-
     if (!$auto_expunge) {
-        echo getButton('SUBMIT', 'expungeButton',_("Expunge"))
-             .'&nbsp;' . _("mailbox") . "\n";
+        echo getButton('SUBMIT', 'expungeButton',_("Expunge")) ."\n";
     }
 
-    echo getButton('SUBMIT', 'markRead',_("Read"));
-    echo getButton('SUBMIT', 'markUnread',_("Unread"));
+    echo getButton('SUBMIT', 'markRead',_("Read")) . "\n";
+    echo getButton('SUBMIT', 'markUnread',_("Unread")) . "\n";
     echo getButton('SUBMIT', 'delete',_("Delete")) ."&nbsp;\n";
     if (!strpos($php_self,'mailbox')) {
         $location = $php_self.'?mailbox=INBOX&amp;startMessage=1';
@@ -762,9 +772,9 @@ function mail_message_listing_beginning ($imapConnection,
 
 //    $location = urlencode($location);
 
-    echo '<INPUT TYPE="HIDDEN" NAME="location" VALUE="'.$location.'">';
-    echo "</TD>\n"
-         . "   </TR>\n";
+    echo '<input type="hidden" name="location" value="'.$location.'">';
+    echo "</td>\n"
+         . "   </tr>\n";
 
     /* draws thread sorting links */
     if ($allow_thread_sort == TRUE) {
@@ -785,7 +795,7 @@ function mail_message_listing_beginning ($imapConnection,
                  , '', '', '' );
     }
 
-    echo "</TABLE></td></tr></table></td></tr>\n";
+    echo "</table></td></tr></table></td></tr>\n";
 
     do_hook('mailbox_form_before');
 
@@ -802,7 +812,7 @@ function mail_message_listing_beginning ($imapConnection,
 function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color) {
   if ($num_msgs) {
     /* space between list and footer */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'" COLSPAN="1">';
+    echo '<tr><td height="5" bgcolor="'.$color[4].'" colspan="1">';
 
     echo '</td></tr><tr><td>';
     echo html_tag( 'table',
@@ -822,7 +832,6 @@ function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $colo
     /* End of message-list table */
 
     do_hook('mailbox_index_after');
-    echo "</FORM>\n";
 }
 
 function printHeader($mailbox, $sort, $color, $showsort=true) {
@@ -873,7 +882,12 @@ function printHeader($mailbox, $sort, $color, $showsort=true) {
             echo "</td>\n";
             break;
         case 6: /* size */
-            echo html_tag( 'td', '<b>' . _("Size") . '</b>', 'center', '', 'width="5%" nowrap' );
+            echo html_tag( 'td' ,'' , 'left', '', 'width="5%" nowrap' )
+                 . '<b>' . _("Size") . '</b>';
+            if ($showsort) {
+                ShowSortButton($sort, $mailbox, 8, 9);
+            }
+            echo "</td>\n";
             break;
         }
     }
@@ -907,8 +921,8 @@ function ShowSortButton($sort, $mailbox, $Up, $Down ) {
     /* Now that we have everything figured out, show the actual button. */
     echo ' <a href="' . $source_url .'?newsort=' . $which
          . '&amp;startMessage=1&amp;mailbox=' . urlencode($mailbox)
-         . '"><IMG SRC="../images/' . $img
-         . '" BORDER=0 WIDTH=12 HEIGHT=10 ALT="sort"></a>';
+         . '"><img src="../images/' . $img
+         . '" border="0" width="12" height="10" alt="sort"></a>';
 }
 
 function get_selectall_link($start_msg, $sort) {
@@ -959,7 +973,7 @@ function get_selectall_link($start_msg, $sort) {
         } else {
             $result .= _("Select All");
         }
-        $result .= "</A>\n";
+        $result .= "</a>\n";
     }
 
     /* Return our final result. */
@@ -990,9 +1004,9 @@ function get_msgcnt_str($start_msg, $end_msg, $num_msgs) {
 function get_paginator_link($box, $start_msg, $use, $text) {
     global $PHP_SELF;
 
-    $result = "<A HREF=\"right_main.php?use_mailbox_cache=$use"
+    $result = "<a href=\"right_main.php?use_mailbox_cache=$use"
             . "&amp;startMessage=$start_msg&amp;mailbox=$box\" "
-            . ">$text</A>";
+            . ">$text</a>";
     return ($result);
 /*
     if (preg_match('/^(.+)\?.+$/',$PHP_SELF,$regs)) {
@@ -1053,9 +1067,9 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
         $nxt_str = get_paginator_link($box, $next_grp, $use, _("Next"));
     } else if (($next_grp > $num_msgs) && ($prev_grp >= 0)) {
         $prv_str = get_paginator_link($box, $prev_grp, $use, _("Previous"));
-        $nxt_str = "<FONT COLOR=\"$color[9]\">"._("Next")."</FONT>\n";
+        $nxt_str = "<font color=\"$color[9]\">"._("Next")."</font>\n";
     } else if (($next_grp <= $num_msgs) && ($prev_grp < 0)) {
-        $prv_str = "<FONT COLOR=\"$color[9]\">"._("Previous") . '</FONT>';
+        $prv_str = "<font color=\"$color[9]\">"._("Previous") . '</font>';
         $nxt_str = get_paginator_link($box, $next_grp, $use, _("Next"));
     }
 
@@ -1126,7 +1140,7 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
         /*
          * I am leaving this debug code here, commented out, because
          * it is a really nice way to see what the above code is doing.
-	 */
+         */
          // echo "qts =  $q1_pgs/$q2_pgs/$q3_pgs/$q4_pgs = "
          //     . ($q1_pgs + $q2_pgs + $q3_pgs + $q4_pgs) . '<br>';
 
@@ -1174,16 +1188,16 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
             }
         }
     } else if ($PG_SHOWNUM == 999999) {
-        $pg_str = "<A HREF=\"right_main.php?PG_SHOWALL=0"
+        $pg_str = "<a href=\"right_main.php?PG_SHOWALL=0"
                 . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                . ">" ._("Paginate") . '</A>' . $spc;
+                . ">" ._("Paginate") . '</a>' . $spc;
     }
 
     /* If necessary, compute the 'show all' string. */
     if (($prv_str != '') || ($nxt_str != '')) {
-        $all_str = "<A HREF=\"right_main.php?PG_SHOWALL=1"
+        $all_str = "<a href=\"right_main.php?PG_SHOWALL=1"
                  . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                 . ">" . _("Show All") . '</A>';
+                 . ">" . _("Show All") . '</a>';
     }
 
     /* Last but not least, get the value for the toggle all link. */
@@ -1272,11 +1286,11 @@ function getMbxList($imapConnection) {
     global $lastTargetMailbox;
     echo  '         <small>&nbsp;<tt><select name="targetMailbox">';
     echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) );
-    echo '         </SELECT></TT>&nbsp;';
+    echo '         </select></tt>&nbsp;';
 }
 
 function getButton($type, $name, $value) {
-    return '<INPUT TYPE="'.$type.'" NAME="'.$name.'" VALUE="'.$value . '">';
+    return '<input type="'.$type.'" name="'.$name.'" value="'.$value . '">';
 }
 
 function getSmallStringCell($string, $align) {
@@ -1316,5 +1330,3 @@ function handleAsSent($mailbox) {
     return $handleAsSent_result;
 }
 
-// vim: et ts=4
-?>
\ No newline at end of file
