@@ -7,14 +7,16 @@
  *   deletes or moves currently displayed message and displays
  *   next or previous message.
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
+ * Copyright (c) 1999-2010 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: setup.php,v 1.23.2.10 2006/02/03 22:27:52 jervfors Exp $
+ * $Id: setup.php 13917 2010-02-20 19:31:44Z pdontthink $
  * @package plugins
  * @subpackage delete_move_next
  */
 
+//FIXME: all functionality needs to be moved out of the setup.php file!
+
 /**
  * Initialize the plugin
  * @return void
@@ -122,12 +124,12 @@ function delete_move_expunge_from_all($id) {
 
 function delete_move_next_action() {
 
-    global $PHP_SELF;
-
-    if ( sqgetGlobalVar('delete_id', $delete_id, SQ_GET) ) {
+    if ( sqgetGlobalVar('unread_id', $unread_id, SQ_GET) ) {
+        delete_move_next_unread();
+    } else if ( sqgetGlobalVar('delete_id', $delete_id, SQ_GET) ) {
         delete_move_next_delete();
         fix_sort_array();
-    } elseif ( sqgetGlobalVar('move_id', $move_id, SQ_POST) ) {
+    } else if ( sqgetGlobalVar('move_id', $move_id, SQ_POST) ) {
         delete_move_next_move();
         fix_sort_array();
     }
@@ -156,7 +158,7 @@ function delete_move_next_read($currloc) {
            $color, $where, $what, $currentArrayIndex, $passed_id,
            $mailbox, $sort, $startMessage, $delete_id, $move_id,
            $imapConnection, $auto_expunge, $move_to_trash, $mbx_response,
-           $uid_support, $passed_ent_id;
+           $uid_support, $passed_ent_id, $delete_move_next_show_unread;
 
     $urlMailbox = urlencode($mailbox);
 
@@ -179,20 +181,32 @@ function delete_move_next_read($currloc) {
         /* Base is illegal within documents 
         * $location = get_location();
         * echo "<base href=\"$location/\">" . */
-        echo '<table cellspacing=0 width="100%" border=0 cellpadding=2>'.
+        echo '<table cellspacing="0" width="100%" border="0" cellpadding="2">'.
              '<tr>'.
-                 "<td bgcolor=\"$color[9]\" width=\"100%\" align=center><small>";
+                 "<td bgcolor=\"$color[9]\" width=\"100%\" align=\"center\"><small>";
 
         if ($prev > 0){
-            echo "<a href=\"read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id\">" . _("Delete & Prev") . "</a>" . "&nbsp;|&nbsp;\n";
+            echo "<a href=\"read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Delete &amp; Prev") . "</a>" . "&nbsp;|&nbsp;";
+            if ($delete_move_next_show_unread == 'on') {
+                echo "<a href=\"read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;unread_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Unread &amp; Prev") . "</a>" . "&nbsp;|&nbsp;";
+            }
         }
         else {
-            echo _("Delete & Prev") . "&nbsp;|&nbsp;";
+            echo _("Delete &amp; Prev") . "&nbsp;|&nbsp;";
+            if ($delete_move_next_show_unread == 'on') {
+                echo _("Unread &amp; Prev") . "&nbsp;|&nbsp;";
+            }
         }
         if ($next > 0){
-            echo "<a href=\"read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id\">" . _("Delete & Next") . "</a>\n";
+            if ($delete_move_next_show_unread == 'on') {
+                echo "<a href=\"read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;unread_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Unread &amp; Next") . "</a>&nbsp;|&nbsp;";
+            }
+            echo "<a href=\"read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Delete &amp; Next") . "</a>";
         } else {
-            echo _("Delete & Next");
+            if ($delete_move_next_show_unread == 'on') {
+                echo _("Unread &amp; Next") . "&nbsp;|&nbsp;";
+            }
+            echo _("Delete &amp; Next");
         }
         echo '</small></td></tr>';
 
@@ -240,6 +254,7 @@ function delete_move_next_moveNextForm($next) {
            "<form action=\"read_body.php?mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;passed_id=$next\" method=\"post\"><small>".
             "<input type=\"hidden\" name=\"show_more\" value=\"0\">".
             "<input type=\"hidden\" name=\"move_id\" value=\"$passed_id\">".
+            "<input type=\"hidden\" name=\"smtoken\" value=\"" . sm_generate_security_token() . "\">".
             _("Move to:") .
             ' <select name="targetMailbox">';
     get_move_target_list(); 
@@ -263,6 +278,7 @@ function delete_move_next_moveRightMainForm() {
             "<td bgcolor=\"$color[9]\" width=\"100%\" align=\"center\">".
             "<form action=\"right_main.php?mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage\" method=\"post\"><small>" .
             "<input type=\"hidden\" name=\"move_id\" value=\"$passed_id\">".
+            "<input type=\"hidden\" name=\"smtoken\" value=\"" . sm_generate_security_token() . "\">".
             _("Move to:") .
             ' <select name="targetMailbox">';
     get_move_target_list(); 
@@ -274,13 +290,33 @@ function delete_move_next_moveRightMainForm() {
          '</tr>';
 }
 
+function delete_move_next_unread() {
+    global $imapConnection;
+
+    sqgetGlobalVar('unread_id', $unread_id, SQ_GET);
+    if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_GET)) {
+        $submitted_token = '';
+    }
+
+    // first, validate security token
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
+    sqimap_toggle_flag($imapConnection, $unread_id, '\\Seen', false, true);
+}
+
 function delete_move_next_delete() {
     global $imapConnection, $auto_expunge;
 
     sqgetGlobalVar('delete_id', $delete_id, SQ_GET);
     sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
+    if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_GET)) {
+        $submitted_token = '';
+    }
 
-    sqimap_messages_delete($imapConnection, $delete_id, $delete_id, $mailbox);
+    // first, validate security token
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
+    sqimap_msgs_list_delete($imapConnection, $mailbox, $delete_id);
     if ($auto_expunge) {
         delete_move_expunge_from_all($delete_id);
         // sqimap_mailbox_expunge($imapConnection, $mailbox, true);
@@ -293,10 +329,15 @@ function delete_move_next_move() {
     sqgetGlobalVar('move_id', $move_id, SQ_POST);
     sqgetGlobalVar('mailbox', $mailbox, SQ_FORM);
     sqgetGlobalVar('targetMailbox', $targetMailbox, SQ_POST);
+    if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
+        $submitted_token = '';
+    }
+
+    // first, validate security token
+    sm_validate_security_token($submitted_token, 3600, TRUE);
 
     // Move message
-    sqimap_messages_copy($imapConnection, $move_id, $move_id, $targetMailbox);
-    sqimap_messages_flag($imapConnection, $move_id, $move_id, 'Deleted', true);
+    sqimap_msgs_list_move($imapConnection, $move_id, $targetMailbox);
     if ($auto_expunge) {
         delete_move_expunge_from_all($move_id);
         // sqimap_mailbox_expunge($imapConnection, $mailbox, true);
@@ -309,36 +350,41 @@ function delete_move_next_move() {
 }
 
 function delete_move_next_display_inside() {
-    global $username,$data_dir,
+    global $username,$data_dir, $delete_move_next_show_unread,
         $delete_move_next_t, $delete_move_next_formATtop,
         $delete_move_next_b, $delete_move_next_formATbottom;
 
-    echo "<tr>" . html_tag('td',_("Delete/Move/Next Buttons:"),'right','','valign=top') . "\n".
-         "<td><input type=checkbox name=delete_move_next_ti";
+    echo "<tr>" . html_tag('td',_("Delete/Unread/Move/Next Buttons:"),'right','','valign="top"') . "\n".
+         '<td><input type="checkbox" name="delete_move_next_ti" id="delete_move_next_ti"';
 
     if ($delete_move_next_t == 'on') {
-        echo " checked";
+        echo ' checked="checked"';
     }
-    echo '> ' . _("Display at top").
-         " <input type=checkbox name=delete_move_next_formATtopi";
+    echo '><label for="delete_move_next_ti"> ' . _("Display at top").
+         '</label> <input type="checkbox" name="delete_move_next_formATtopi" id="delete_move_next_formATtopi"';
 
     if ($delete_move_next_formATtop == 'on') {
-        echo ' checked';
+        echo ' checked="checked"';
     }
-    echo '> ' . _("with move option") . '<br>';
+    echo '><label for="delete_move_next_formATtopi"> ' . _("with move option") . '</label><br>';
 
-    echo '<input type=checkbox name=delete_move_next_bi';
+    echo '<input type="checkbox" name="delete_move_next_bi" id="delete_move_next_bi"';
     if($delete_move_next_b != 'off') {
-        echo ' checked';
+        echo ' checked="checked"';
     }
-    echo '> ' . _("Display at bottom") .
-         '<input type=checkbox name=delete_move_next_formATbottomi';
+    echo '><label for="delete_move_next_bi"> ' . _("Display at bottom") .
+         '</label> <input type="checkbox" name="delete_move_next_formATbottomi" id="delete_move_next_formATbottomi"';
 
     if ($delete_move_next_formATbottom != 'off') {
-        echo ' checked';
+        echo ' checked="checked"';
     }
-    echo '> ' . _("with move option") . '<br>'.
-         "</td></tr>\n";
+    echo '><label for="delete_move_next_formATbottomi"> ' . _("with move option") . '</label><br>'.
+         '<input type="checkbox" name="delete_move_next_show_unread" id="delete_move_next_show_unread"';
+    if($delete_move_next_show_unread != 'off') {
+        echo ' checked="checked"';
+    }
+    echo '><label for="delete_move_next_show_unread"> ' . _("Show unread options") .
+         "</label></td></tr>\n";
 }
 
 function delete_move_next_display_save() {
@@ -369,10 +415,16 @@ function delete_move_next_display_save() {
     } else {
         setPref($data_dir, $username, 'delete_move_next_formATbottom', "off");
     }
+
+    if ( sqgetGlobalVar('delete_move_next_show_unread', $delete_move_next_show_unread, SQ_POST) ) {
+        setPref($data_dir, $username, 'delete_move_next_show_unread', 'on');
+    } else {
+        setPref($data_dir, $username, 'delete_move_next_show_unread', "off");
+    }
 }
 
 function delete_move_next_loading_prefs() {
-    global $username,$data_dir,
+    global $username,$data_dir, $delete_move_next_show_unread,
            $delete_move_next_t, $delete_move_next_formATtop,
            $delete_move_next_b, $delete_move_next_formATbottom;
 
@@ -380,7 +432,7 @@ function delete_move_next_loading_prefs() {
     $delete_move_next_b = getPref($data_dir, $username, 'delete_move_next_b');
     $delete_move_next_formATtop = getPref($data_dir, $username, 'delete_move_next_formATtop');
     $delete_move_next_formATbottom = getPref($data_dir, $username, 'delete_move_next_formATbottom');
+    $delete_move_next_show_unread = getPref($data_dir, $username, 'delete_move_next_show_unread');
 
 }
 
-?>
\ No newline at end of file
