@@ -3,12 +3,13 @@
 /**
  * mail_fetch/options.php
  *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Setup of the mailfetch plugin.
  *
- * $Id: options.php,v 1.21.2.6 2004/04/26 22:20:20 kink Exp $
+ * @copyright 1999-2010 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: options.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @package plugins
+ * @subpackage mail_fetch
  */
 
 define('SM_PATH','../../');
@@ -17,6 +18,11 @@ require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'include/load_prefs.php');
 
+// don't load this page if this plugin is not enabled
+//
+global $plugins;
+if (!in_array('mail_fetch', $plugins)) exit;
+
 /* globals */
 sqgetGlobalVar('username',   $username,   SQ_SESSION);
 sqgetGlobalVar('key',        $key,        SQ_COOKIE);
@@ -63,8 +69,16 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
         setPref($data_dir,$username,"mailfetch_port_$mf_sn", (isset($mf_port)?$mf_port:110));
         setPref($data_dir,$username,"mailfetch_alias_$mf_sn", (isset($mf_alias)?$mf_alias:""));
         setPref($data_dir,$username,"mailfetch_user_$mf_sn",(isset($mf_user)?$mf_user:""));
-        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",(isset($mf_pass)?encrypt( $mf_pass )    :""));
-        if( isset($mf_cypher) && $mf_cypher <> 'on' ) SetPref($data_dir,$username,'mailfetch_cypher',    'on');
+        $pass = "";
+        if ( isset($mf_pass) ) {
+            if ( isset($mf_cypher) && $mf_cypher == 'on' ) {
+                setPref($data_dir,$username,"mailfetch_cypher", ($mf_cypher == 'on' ? 'on' : ''));
+                $pass = encrypt($mf_pass);
+            } else {
+                $pass = $mf_pass;
+            }
+        }
+        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",$pass);
         setPref($data_dir,$username,"mailfetch_lmos_$mf_sn",(isset($mf_lmos)?$mf_lmos:""));
         setPref($data_dir,$username,"mailfetch_login_$mf_sn",(isset($mf_login)?$mf_login:""));
         setPref($data_dir,$username,"mailfetch_fref_$mf_sn",(isset($mf_fref)?$mf_fref:""));
@@ -80,8 +94,17 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
         setPref($data_dir,$username,"mailfetch_port_$mf_sn", (isset($mf_port)?$mf_port:110));
         setPref($data_dir,$username,"mailfetch_alias_$mf_sn", (isset($mf_alias)?$mf_alias:""));
         setPref($data_dir,$username,"mailfetch_user_$mf_sn",(isset($mf_user)?$mf_user:""));
-        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",(isset($mf_pass)?encrypt( $mf_pass )    :""));
-        if( $mf_cypher <> 'on' ) setPref($data_dir,$username,"mailfetch_cypher", 'on');
+        $pass = "";
+        if ( isset($mf_pass) ) {
+           if ( isset($mf_cypher) && $mf_cypher == 'on' ) {
+               setPref($data_dir,$username,"mailfetch_cypher", 'on');
+               $pass = encrypt($mf_pass);
+           } else {
+               setPref($data_dir,$username,"mailfetch_cypher", '');
+               $pass = $mf_pass;
+           }
+        }
+        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",$pass);
         setPref($data_dir,$username,"mailfetch_lmos_$mf_sn",(isset($mf_lmos)?$mf_lmos:""));
         setPref($data_dir,$username,"mailfetch_login_$mf_sn",(isset($mf_login)?$mf_login:""));
         setPref($data_dir,$username,"mailfetch_fref_$mf_sn",(isset($mf_fref)?$mf_fref:""));
@@ -159,12 +182,12 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
             html_tag( 'table',
                 html_tag( 'tr',
                     html_tag( 'td',
-                        _("You should be aware that the encryption used to store your password is not perfectly secure.  However, if you are using pop, there is inherently no encryption anyway. Additionally, the encryption that we do to save it on the server can be undone by a hacker reading the source to this file." ) ,
+                        _("You should be aware that the encryption used to store your password is not perfectly secure. However, if you are using pop, there is inherently no encryption anyway. Additionally, the encryption that we do to save it on the server can be undone by a hacker reading the source to this file." ) ,
                     'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td',
-                        _("If you leave password empty, it will be required when you fetch mail.") ,
+                        _("If you leave password empty, it will be asked when you fetch mail.") ,
                     'left' )
                 ) .
                 html_tag( 'tr',
@@ -222,15 +245,15 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
         echo '</select></td></tr>' .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
-                    html_tag( 'td', '<input type="checkbox" name="mf_lmos" checked>' . _("Leave Mail on Server"), 'left' )
+                    html_tag( 'td', '<input type="checkbox" name="mf_lmos" checked>' . _("Leave mail on server"), 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
-                    html_tag( 'td', '<input type="checkbox" name="mf_login">' . _("Check mail during login"), 'left' )
+                    html_tag( 'td', '<input type="checkbox" name="mf_login">' . _("Check mail at login"), 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
-                    html_tag( 'td', '<input type="checkbox" name="mf_fref">' . _("Check mail during folder refresh"), 'left' )
+                    html_tag( 'td', '<input type="checkbox" name="mf_fref">' . _("Check mail at folder refresh"), 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td',
@@ -259,7 +282,7 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
                  '&nbsp;&nbsp;<INPUT TYPE=submit name=mf_action_del value="' . _("Delete") . '">'.
                  '</form>';
         } else {
-            echo _("No-one server in use. Try to add.");
+            echo _("No servers known.");
         }
         echo '</td></tr></table>';
         break;
@@ -348,14 +371,14 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
                     html_tag( 'th', '&nbsp;', 'right' ) .
                     html_tag( 'td',
                         '<input type=checkbox name=mf_login ' . ( ($mailfetch_login_[$mf_sn] == 'on')?'checked':'') .
-                        '>' . _("Check mail during login"),
+                        '>' . _("Check mail at login"),
                     'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
                     html_tag( 'td',
                         '<input type=checkbox name=mf_fref ' . ( ($mailfetch_fref_[$mf_sn] == 'on')?'checked':'') .
-                        '>' . _("Check mail during folder refresh") ,
+                        '>' . _("Check mail at folder refresh") ,
                     'left' )
                 ) .
                 html_tag( 'tr',
@@ -377,7 +400,7 @@ sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
         html_tag( 'table',
             html_tag( 'tr',
                 html_tag( 'td', '<b>' . _("Undefined Function") . '</b>', 'center', $color[9] ) .
-                html_tag( 'td', '<b>' . _("Hey! Wath do You are looking for?") . '</b>', 'center', $color[0] )
+                html_tag( 'td', '<b>' .  _("The function you requested is unknown.") . '</b>', 'center', $color[0] )
             ) ,
         'center', '', 'width="70%"' );
     }
