@@ -5,9 +5,9 @@
  *
  * Deletes a meesage from the IMAP server
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: delete_message.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: delete_message.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  */
 
@@ -29,6 +29,9 @@ sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 
 sqgetGlobalVar('message', $message, SQ_GET);
 sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
+if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_GET)) {
+    $submitted_token = '';
+}
 /* end globals */
 
 if (isset($_GET['saved_draft'])) {
@@ -50,6 +53,9 @@ if (isset($_GET['startMessage'])) {
     $startMessage = (int) $_GET['startMessage'];
 }
 
+// first, validate security token
+sm_validate_security_token($submitted_token, 3600, TRUE);
+
 $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 sqimap_mailbox_select($imapConnection, $mailbox);
@@ -72,6 +78,7 @@ $location = get_location();
 
 if (isset($where) && isset($what)) {
     header("Location: $location/search.php?where=" . $where .
+           '&smtoken=' . sm_generate_security_token() .
            '&what=' . $what . '&mailbox=' . urlencode($mailbox));
 } else {
     if (!empty($saved_draft) || !empty($mail_sent)) {
